# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CreateBrowserRequest(BaseModel):
    """
    CreateBrowserRequest
    """ # noqa: E501
    uc: Optional[StrictBool] = Field(default=True, description="uc")
    proxy: Optional[StrictStr] = Field(default=None, description="proxy")
    window_size: Optional[List[StrictInt]] = Field(default=None, description="window_size")
    user_agent: Optional[StrictStr] = Field(default=None, description="user_agent")
    disable_gpu: Optional[StrictBool] = Field(default=False, description="disable_gpu")
    disable_images: Optional[StrictBool] = Field(default=False, description="disable_images")
    disable_javascript: Optional[StrictBool] = Field(default=False, description="disable_javascript")
    extensions: Optional[List[StrictStr]] = Field(default=None, description="extensions")
    custom_args: Optional[List[StrictStr]] = Field(default=None, description="custom_args")
    profile_name: Optional[StrictStr] = Field(default=None, description="profile_name")
    __properties: ClassVar[List[str]] = ["uc", "proxy", "window_size", "user_agent", "disable_gpu", "disable_images", "disable_javascript", "extensions", "custom_args", "profile_name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateBrowserRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateBrowserRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "uc": obj.get("uc") if obj.get("uc") is not None else True,
            "proxy": obj.get("proxy"),
            "window_size": obj.get("window_size"),
            "user_agent": obj.get("user_agent"),
            "disable_gpu": obj.get("disable_gpu") if obj.get("disable_gpu") is not None else False,
            "disable_images": obj.get("disable_images") if obj.get("disable_images") is not None else False,
            "disable_javascript": obj.get("disable_javascript") if obj.get("disable_javascript") is not None else False,
            "extensions": obj.get("extensions"),
            "custom_args": obj.get("custom_args"),
            "profile_name": obj.get("profile_name")
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from airbrowser_client.models.base_response import BaseResponse
from airbrowser_client.models.browsers_request import BrowsersRequest
from airbrowser_client.models.click_request import ClickRequest
from airbrowser_client.models.console_logs_request import ConsoleLogsRequest
from airbrowser_client.models.cookies_request import CookiesRequest
from airbrowser_client.models.create_browser_request import CreateBrowserRequest
from airbrowser_client.models.create_profile_request import CreateProfileRequest
from airbrowser_client.models.detect_coordinates_request import DetectCoordinatesRequest
from airbrowser_client.models.dialog_request import DialogRequest
from airbrowser_client.models.emulate_request import EmulateRequest
from airbrowser_client.models.error_response import ErrorResponse
from airbrowser_client.models.execute_cdp_request import ExecuteCdpRequest
from airbrowser_client.models.execute_script_request import ExecuteScriptRequest
from airbrowser_client.models.fill_form_request import FillFormRequest
from airbrowser_client.models.generic_response import GenericResponse
from airbrowser_client.models.gui_click_request import GuiClickRequest
from airbrowser_client.models.gui_hover_xy_request import GuiHoverXyRequest
from airbrowser_client.models.gui_press_keys_xy_request import GuiPressKeysXyRequest
from airbrowser_client.models.gui_type_xy_request import GuiTypeXyRequest
from airbrowser_client.models.health_status import HealthStatus
from airbrowser_client.models.history_request import HistoryRequest
from airbrowser_client.models.mouse_request import MouseRequest
from airbrowser_client.models.navigate_browser_request import NavigateBrowserRequest
from airbrowser_client.models.network_logs_request import NetworkLogsRequest
from airbrowser_client.models.performance_request import PerformanceRequest
from airbrowser_client.models.pool_scaled import PoolScaled
from airbrowser_client.models.press_keys_request import PressKeysRequest
from airbrowser_client.models.profile_info import ProfileInfo
from airbrowser_client.models.profile_list_data import ProfileListData
from airbrowser_client.models.profile_list_response import ProfileListResponse
from airbrowser_client.models.profile_response import ProfileResponse
from airbrowser_client.models.resize_request import ResizeRequest
from airbrowser_client.models.scale_data import ScaleData
from airbrowser_client.models.scale_pool import ScalePool
from airbrowser_client.models.scroll_request import ScrollRequest
from airbrowser_client.models.select_request import SelectRequest
from airbrowser_client.models.snapshot_request import SnapshotRequest
from airbrowser_client.models.tabs_request import TabsRequest
from airbrowser_client.models.take_screenshot_request import TakeScreenshotRequest
from airbrowser_client.models.type_text_request import TypeTextRequest
from airbrowser_client.models.upload_file_request import UploadFileRequest
from airbrowser_client.models.wait_element_request import WaitElementRequest




# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from airbrowser_client.models.combined_scroll_request import CombinedScrollRequest

class TestCombinedScrollRequest(unittest.TestCase):
    """CombinedScrollRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CombinedScrollRequest:
        """Test CombinedScrollRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CombinedScrollRequest`
        """
        model = CombinedScrollRequest()
        if include_optional:
            return CombinedScrollRequest(
                selector = '',
                by = 'css',
                x = 56,
                y = 56,
                delta_x = 56,
                delta_y = 56,
                behavior = 'smooth'
            )
        else:
            return CombinedScrollRequest(
        )
        """

    def testCombinedScrollRequest(self):
        """Test CombinedScrollRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from airbrowser_client.api.pool_api import PoolApi


class TestPoolApi(unittest.TestCase):
    """PoolApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PoolApi()

    def tearDown(self) -> None:
        pass

    def test_scale_pool(self) -> None:
        """Test case for scale_pool

        Scale the browser pool to a new maximum size
        """
        pass

    def test_shutdown_server(self) -> None:
        """Test case for shutdown_server

        Gracefully shutdown the browser pool server
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from airbrowser_client.api.browser_api import BrowserApi
from airbrowser_client.api.health_api import HealthApi
from airbrowser_client.api.pool_api import PoolApi
from airbrowser_client.api.profiles_api import ProfilesApi




# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from airbrowser_client.models.wait_element_request import WaitElementRequest

class TestWaitElementRequest(unittest.TestCase):
    """WaitElementRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WaitElementRequest:
        """Test WaitElementRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WaitElementRequest`
        """
        model = WaitElementRequest()
        if include_optional:
            return WaitElementRequest(
                selector = '',
                by = 'css',
                until = 'visible',
                timeout = 56
            )
        else:
            return WaitElementRequest(
                selector = '',
                until = 'visible',
        )
        """

    def testWaitElementRequest(self):
        """Test WaitElementRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.13.0"

# Define package exports
__all__ = [
    "BrowserApi",
    "HealthApi",
    "PoolApi",
    "ProfilesApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "BaseResponse",
    "BrowsersRequest",
    "ClickRequest",
    "ConsoleLogsRequest",
    "CookiesRequest",
    "CreateBrowserRequest",
    "CreateProfileRequest",
    "DetectCoordinatesRequest",
    "DialogRequest",
    "EmulateRequest",
    "ErrorResponse",
    "ExecuteCdpRequest",
    "ExecuteScriptRequest",
    "FillFormRequest",
    "GenericResponse",
    "GuiClickRequest",
    "GuiHoverXyRequest",
    "GuiPressKeysXyRequest",
    "GuiTypeXyRequest",
    "HealthStatus",
    "HistoryRequest",
    "MouseRequest",
    "NavigateBrowserRequest",
    "NetworkLogsRequest",
    "PerformanceRequest",
    "PoolScaled",
    "PressKeysRequest",
    "ProfileInfo",
    "ProfileListData",
    "ProfileListResponse",
    "ProfileResponse",
    "ResizeRequest",
    "ScaleData",
    "ScalePool",
    "ScrollRequest",
    "SelectRequest",
    "SnapshotRequest",
    "TabsRequest",
    "TakeScreenshotRequest",
    "TypeTextRequest",
    "UploadFileRequest",
    "WaitElementRequest",
]

# import apis into sdk package
from airbrowser_client.api.browser_api import BrowserApi as BrowserApi
from airbrowser_client.api.health_api import HealthApi as HealthApi
from airbrowser_client.api.pool_api import PoolApi as PoolApi
from airbrowser_client.api.profiles_api import ProfilesApi as ProfilesApi

# import ApiClient
from airbrowser_client.api_response import ApiResponse as ApiResponse
from airbrowser_client.api_client import ApiClient as ApiClient
from airbrowser_client.configuration import Configuration as Configuration
from airbrowser_client.exceptions import OpenApiException as OpenApiException
from airbrowser_client.exceptions import ApiTypeError as ApiTypeError
from airbrowser_client.exceptions import ApiValueError as ApiValueError
from airbrowser_client.exceptions import ApiKeyError as ApiKeyError
from airbrowser_client.exceptions import ApiAttributeError as ApiAttributeError
from airbrowser_client.exceptions import ApiException as ApiException

# import models into sdk package
from airbrowser_client.models.base_response import BaseResponse as BaseResponse
from airbrowser_client.models.browsers_request import BrowsersRequest as BrowsersRequest
from airbrowser_client.models.click_request import ClickRequest as ClickRequest
from airbrowser_client.models.console_logs_request import ConsoleLogsRequest as ConsoleLogsRequest
from airbrowser_client.models.cookies_request import CookiesRequest as CookiesRequest
from airbrowser_client.models.create_browser_request import CreateBrowserRequest as CreateBrowserRequest
from airbrowser_client.models.create_profile_request import CreateProfileRequest as CreateProfileRequest
from airbrowser_client.models.detect_coordinates_request import DetectCoordinatesRequest as DetectCoordinatesRequest
from airbrowser_client.models.dialog_request import DialogRequest as DialogRequest
from airbrowser_client.models.emulate_request import EmulateRequest as EmulateRequest
from airbrowser_client.models.error_response import ErrorResponse as ErrorResponse
from airbrowser_client.models.execute_cdp_request import ExecuteCdpRequest as ExecuteCdpRequest
from airbrowser_client.models.execute_script_request import ExecuteScriptRequest as ExecuteScriptRequest
from airbrowser_client.models.fill_form_request import FillFormRequest as FillFormRequest
from airbrowser_client.models.generic_response import GenericResponse as GenericResponse
from airbrowser_client.models.gui_click_request import GuiClickRequest as GuiClickRequest
from airbrowser_client.models.gui_hover_xy_request import GuiHoverXyRequest as GuiHoverXyRequest
from airbrowser_client.models.gui_press_keys_xy_request import GuiPressKeysXyRequest as GuiPressKeysXyRequest
from airbrowser_client.models.gui_type_xy_request import GuiTypeXyRequest as GuiTypeXyRequest
from airbrowser_client.models.health_status import HealthStatus as HealthStatus
from airbrowser_client.models.history_request import HistoryRequest as HistoryRequest
from airbrowser_client.models.mouse_request import MouseRequest as MouseRequest
from airbrowser_client.models.navigate_browser_request import NavigateBrowserRequest as NavigateBrowserRequest
from airbrowser_client.models.network_logs_request import NetworkLogsRequest as NetworkLogsRequest
from airbrowser_client.models.performance_request import PerformanceRequest as PerformanceRequest
from airbrowser_client.models.pool_scaled import PoolScaled as PoolScaled
from airbrowser_client.models.press_keys_request import PressKeysRequest as PressKeysRequest
from airbrowser_client.models.profile_info import ProfileInfo as ProfileInfo
from airbrowser_client.models.profile_list_data import ProfileListData as ProfileListData
from airbrowser_client.models.profile_list_response import ProfileListResponse as ProfileListResponse
from airbrowser_client.models.profile_response import ProfileResponse as ProfileResponse
from airbrowser_client.models.resize_request import ResizeRequest as ResizeRequest
from airbrowser_client.models.scale_data import ScaleData as ScaleData
from airbrowser_client.models.scale_pool import ScalePool as ScalePool
from airbrowser_client.models.scroll_request import ScrollRequest as ScrollRequest
from airbrowser_client.models.select_request import SelectRequest as SelectRequest
from airbrowser_client.models.snapshot_request import SnapshotRequest as SnapshotRequest
from airbrowser_client.models.tabs_request import TabsRequest as TabsRequest
from airbrowser_client.models.take_screenshot_request import TakeScreenshotRequest as TakeScreenshotRequest
from airbrowser_client.models.type_text_request import TypeTextRequest as TypeTextRequest
from airbrowser_client.models.upload_file_request import UploadFileRequest as UploadFileRequest
from airbrowser_client.models.wait_element_request import WaitElementRequest as WaitElementRequest




# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from airbrowser_client.api.auto_browser_api import AutoBrowserApi


class TestAutoBrowserApi(unittest.TestCase):
    """AutoBrowserApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AutoBrowserApi()

    def tearDown(self) -> None:
        pass

    def test_browsers(self) -> None:
        """Test case for browsers

        Admin: list all, get info, or close all browsers
        """
        pass

    def test_check_element(self) -> None:
        """Test case for check_element

        Check if element exists or is visible
        """
        pass

    def test_click(self) -> None:
        """Test case for click

        Click element
        """
        pass

    def test_close_browser(self) -> None:
        """Test case for close_browser

        Close browser instance
        """
        pass

    def test_console_logs(self) -> None:
        """Test case for console_logs

        Console logs: get or clear
        """
        pass

    def test_create_browser(self) -> None:
        """Test case for create_browser

        Create browser instance
        """
        pass

    def test_detect_coordinates(self) -> None:
        """Test case for detect_coordinates

        Detect element coordinates using vision
        """
        pass

    def test_dialog(self) -> None:
        """Test case for dialog

        Dialogs: get, accept, dismiss
        """
        pass

    def test_emulate(self) -> None:
        """Test case for emulate

        Emulation: set, clear, list_devices
        """
        pass

    def test_execute_script(self) -> None:
        """Test case for execute_script

        Execute JavaScript
        """
        pass

    def test_fill_form(self) -> None:
        """Test case for fill_form

        Fill multiple form fields
        """
        pass

    def test_get_content(self) -> None:
        """Test case for get_content

        Get page HTML
        """
        pass

    def test_get_element_data(self) -> None:
        """Test case for get_element_data

        Get element text, attribute, or property
        """
        pass

    def test_get_url(self) -> None:
        """Test case for get_url

        Get current URL
        """
        pass

    def test_gui_click(self) -> None:
        """Test case for gui_click

        GUI click by selector or coordinates
        """
        pass

    def test_gui_hover_xy(self) -> None:
        """Test case for gui_hover_xy

        GUI hover at coordinates
        """
        pass

    def test_gui_press_keys_xy(self) -> None:
        """Test case for gui_press_keys_xy

        Press keys at coordinates (click to focus, then send keys)
        """
        pass

    def test_gui_type_xy(self) -> None:
        """Test case for gui_type_xy

        GUI type at coordinates - clicks then types text
        """
        pass

    def test_history(self) -> None:
        """Test case for history

        History: back, forward, or refresh
        """
        pass

    def test_mouse(self) -> None:
        """Test case for mouse

        Mouse: hover or drag
        """
        pass

    def test_navigate_browser(self) -> None:
        """Test case for navigate_browser

        Navigate to URL
        """
        pass

    def test_network_logs(self) -> None:
        """Test case for network_logs

        Network logs: get or clear
        """
        pass

    def test_performance(self) -> None:
        """Test case for performance

        Performance: start_trace, stop_trace, metrics, analyze
        """
        pass

    def test_press_keys(self) -> None:
        """Test case for press_keys

        Press keyboard keys
        """
        pass

    def test_resize(self) -> None:
        """Test case for resize

        Resize viewport
        """
        pass

    def test_scroll(self) -> None:
        """Test case for scroll

        Scroll to element/coords or by delta
        """
        pass

    def test_select(self) -> None:
        """Test case for select

        Select dropdown: select option or get options
        """
        pass

    def test_snapshot(self) -> None:
        """Test case for snapshot

        DOM or accessibility snapshot
        """
        pass

    def test_tabs(self) -> None:
        """Test case for tabs

        Tabs: list, new, switch, close, current
        """
        pass

    def test_take_screenshot(self) -> None:
        """Test case for take_screenshot

        Take screenshot
        """
        pass

    def test_type_text(self) -> None:
        """Test case for type_text

        Type text into element
        """
        pass

    def test_upload_file(self) -> None:
        """Test case for upload_file

        Upload file to input
        """
        pass

    def test_wait_element(self) -> None:
        """Test case for wait_element

        Wait for element to be visible or hidden
        """
        pass

    def test_what_is_visible(self) -> None:
        """Test case for what_is_visible

        AI page analysis - what's visible
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from airbrowser_client.api.browser_api import BrowserApi


class TestBrowserApi(unittest.TestCase):
    """BrowserApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BrowserApi()

    def tearDown(self) -> None:
        pass

    def test_check_element(self) -> None:
        """Test case for check_element

        Check if element exists or is visible
        """
        pass

    def test_click(self) -> None:
        """Test case for click

        Click element
        """
        pass

    def test_close_all_browsers(self) -> None:
        """Test case for close_all_browsers

        Close all active browser instances
        """
        pass

    def test_close_browser(self) -> None:
        """Test case for close_browser

        Close a browser instance
        """
        pass

    def test_console_logs(self) -> None:
        """Test case for console_logs

        Get or clear console logs
        """
        pass

    def test_create_browser(self) -> None:
        """Test case for create_browser

        Create a new browser instance
        """
        pass

    def test_delete_browser(self) -> None:
        """Test case for delete_browser

        Close and remove a browser instance
        """
        pass

    def test_detect_coordinates(self) -> None:
        """Test case for detect_coordinates

        Detect element coordinates using AI vision
        """
        pass

    def test_dialog(self) -> None:
        """Test case for dialog

        Manage browser dialogs: get, accept, or dismiss
        """
        pass

    def test_emulate(self) -> None:
        """Test case for emulate

        Manage device emulation: set, clear, or list_devices
        """
        pass

    def test_execute_script(self) -> None:
        """Test case for execute_script

        Execute JavaScript
        """
        pass

    def test_fill_form(self) -> None:
        """Test case for fill_form

        Fill multiple form fields
        """
        pass

    def test_get_browser(self) -> None:
        """Test case for get_browser

        Get browser instance details
        """
        pass

    def test_get_browser_status(self) -> None:
        """Test case for get_browser_status

        Get browser status
        """
        pass

    def test_get_content(self) -> None:
        """Test case for get_content

        Get page HTML content
        """
        pass

    def test_get_element_data(self) -> None:
        """Test case for get_element_data

        Get element text, attribute, or property
        """
        pass

    def test_get_pool_status(self) -> None:
        """Test case for get_pool_status

        Get browser pool status
        """
        pass

    def test_get_url(self) -> None:
        """Test case for get_url

        Get current page URL
        """
        pass

    def test_gui_click(self) -> None:
        """Test case for gui_click

        Click using selector or screen coordinates
        """
        pass

    def test_history(self) -> None:
        """Test case for history

        Execute history action: back, forward, or refresh
        """
        pass

    def test_list_browsers(self) -> None:
        """Test case for list_browsers

        List all active browser instances
        """
        pass

    def test_mouse(self) -> None:
        """Test case for mouse

        Mouse action: hover or drag
        """
        pass

    def test_navigate_browser(self) -> None:
        """Test case for navigate_browser

        Navigate to a URL
        """
        pass

    def test_network_logs(self) -> None:
        """Test case for network_logs

        Get or clear network logs
        """
        pass

    def test_performance(self) -> None:
        """Test case for performance

        Manage performance: start_trace, stop_trace, metrics, or analyze
        """
        pass

    def test_press_keys(self) -> None:
        """Test case for press_keys

        Press keys on an element
        """
        pass

    def test_resize(self) -> None:
        """Test case for resize

        Resize viewport
        """
        pass

    def test_scroll(self) -> None:
        """Test case for scroll

        Scroll to element/coordinates (absolute) or by delta (relative)
        """
        pass

    def test_select(self) -> None:
        """Test case for select

        Select dropdown: select option or get options
        """
        pass

    def test_tabs(self) -> None:
        """Test case for tabs

        Manage browser tabs: list, new, switch, close, or current
        """
        pass

    def test_take_screenshot(self) -> None:
        """Test case for take_screenshot

        Take a screenshot
        """
        pass

    def test_take_snapshot(self) -> None:
        """Test case for take_snapshot

        Take DOM/accessibility snapshot
        """
        pass

    def test_type_text(self) -> None:
        """Test case for type_text

        Type text into an element
        """
        pass

    def test_upload_file(self) -> None:
        """Test case for upload_file

        Upload a file
        """
        pass

    def test_wait_element(self) -> None:
        """Test case for wait_element

        Wait for element to become visible or hidden
        """
        pass

    def test_what_is_visible(self) -> None:
        """Test case for what_is_visible

        Analyze visible page content using AI
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from airbrowser_client.api.profiles_api import ProfilesApi


class TestProfilesApi(unittest.TestCase):
    """ProfilesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProfilesApi()

    def tearDown(self) -> None:
        pass

    def test_create_profile(self) -> None:
        """Test case for create_profile

        Create a new browser profile
        """
        pass

    def test_delete_profile(self) -> None:
        """Test case for delete_profile

        Delete a browser profile
        """
        pass

    def test_get_profile(self) -> None:
        """Test case for get_profile

        Get profile information
        """
        pass

    def test_list_profiles(self) -> None:
        """Test case for list_profiles

        List all browser profiles
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Airbrowser API

    Undetectable Chrome-in-Docker for developers and agents (REST + MCP)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from airbrowser_client.models.browser_config import BrowserConfig

class TestBrowserConfig(unittest.TestCase):
    """BrowserConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BrowserConfig:
        """Test BrowserConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BrowserConfig`
        """
        model = BrowserConfig()
        if include_optional:
            return BrowserConfig(
                profile_name = 'dev-session',
                proxy = '',
                user_agent = '',
                window_size = [
                    56
                    ],
                disable_gpu = True,
                disable_images = True,
                disable_javascript = True,
                extensions = [
                    ''
                    ],
                custom_args = [
                    ''
                    ]
            )
        else:
            return BrowserConfig(
        )
        """

    def testBrowserConfig(self):
        """Test BrowserConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
